:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/_topologies.py#L748-L1002



elpigraph.fineTuneBR
====================

.. currentmodule:: elpigraph

.. autofunction:: fineTuneBR